import * as iam from 'aws-cdk-lib/aws-iam';
import { Resource, IResource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { State } from './state';
/**
 * (experimental) Represents an AWS IoT Events detector model.
 *
 * @experimental
 */
export interface IDetectorModel extends IResource {
    /**
     * (experimental) The name of the detector model.
     *
     * @experimental
     * @attribute true
     */
    readonly detectorModelName: string;
}
/**
 * (experimental) Information about the order in which events are evaluated and how actions are executed.
 *
 * @experimental
 */
export declare enum EventEvaluation {
    /**
     * (experimental) When setting to BATCH, variables within a state are updated and events within a state are performed only after all event conditions are evaluated.
     *
     * @experimental
     */
    BATCH = "BATCH",
    /**
     * (experimental) When setting to SERIAL, variables are updated and event conditions are evaluated in the order that the events are defined.
     *
     * @experimental
     */
    SERIAL = "SERIAL"
}
/**
 * (experimental) Properties for defining an AWS IoT Events detector model.
 *
 * @experimental
 */
export interface DetectorModelProps {
    /**
     * (experimental) The name of the detector model.
     *
     * @default - CloudFormation will generate a unique name of the detector model
     * @experimental
     */
    readonly detectorModelName?: string;
    /**
     * (experimental) A brief description of the detector model.
     *
     * @default none
     * @experimental
     */
    readonly description?: string;
    /**
     * (experimental) Information about the order in which events are evaluated and how actions are executed.
     *
     * When setting to SERIAL, variables are updated and event conditions are evaluated in the order
     * that the events are defined.
     * When setting to BATCH, variables within a state are updated and events within a state are
     * performed only after all event conditions are evaluated.
     *
     * @default EventEvaluation.BATCH
     * @experimental
     */
    readonly evaluationMethod?: EventEvaluation;
    /**
     * (experimental) The value used to identify a detector instance.
     *
     * When a device or system sends input, a new
     * detector instance with a unique key value is created. AWS IoT Events can continue to route
     * input to its corresponding detector instance based on this identifying information.
     *
     * This parameter uses a JSON-path expression to select the attribute-value pair in the message
     * payload that is used for identification. To route the message to the correct detector instance,
     * the device must send a message payload that contains the same attribute-value.
     *
     * @default - none (single detector instance will be created and all inputs will be routed to it)
     * @experimental
     */
    readonly detectorKey?: string;
    /**
     * (experimental) The state that is entered at the creation of each detector.
     *
     * @experimental
     */
    readonly initialState: State;
    /**
     * (experimental) The role that grants permission to AWS IoT Events to perform its operations.
     *
     * @default - a role will be created with default permissions
     * @experimental
     */
    readonly role?: iam.IRole;
}
/**
 * (experimental) Defines an AWS IoT Events detector model in this stack.
 *
 * @experimental
 */
export declare class DetectorModel extends Resource implements IDetectorModel {
    /**
     * (experimental) Import an existing detector model.
     *
     * @experimental
     */
    static fromDetectorModelName(scope: Construct, id: string, detectorModelName: string): IDetectorModel;
    /**
     * (experimental) The name of the detector model.
     *
     * @experimental
     */
    readonly detectorModelName: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: DetectorModelProps);
}
