import { IInput } from './input';
/**
 * (experimental) Expression for events in Detector Model state.
 *
 * @see https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html
 * @experimental
 */
export declare abstract class Expression {
    /**
     * (experimental) Create a expression from the given string.
     *
     * @experimental
     */
    static fromString(value: string): Expression;
    /**
     * (experimental) Create a expression for function `currentInput()`.
     *
     * It is evaluated to true if the specified input message was received.
     *
     * @experimental
     */
    static currentInput(input: IInput): Expression;
    /**
     * (experimental) Create a expression for get an input attribute as `$input.TemperatureInput.temperatures[2]`.
     *
     * @experimental
     */
    static inputAttribute(input: IInput, path: string): Expression;
    /**
     * (experimental) Create a expression for the Equal operator.
     *
     * @experimental
     */
    static eq(left: Expression, right: Expression): Expression;
    /**
     * (experimental) Create a expression for the AND operator.
     *
     * @experimental
     */
    static and(left: Expression, right: Expression): Expression;
    /**
     * @experimental
     */
    constructor();
    /**
     * (experimental) This is called to evaluate the expression.
     *
     * @experimental
     */
    abstract evaluate(): string;
}
