import * as iam from 'aws-cdk-lib/aws-iam';
import { Resource, IResource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * (experimental) Represents an AWS IoT Events input.
 *
 * @experimental
 */
export interface IInput extends IResource {
    /**
     * (experimental) The name of the input.
     *
     * @experimental
     * @attribute true
     */
    readonly inputName: string;
    /**
     * (experimental) The ARN of the input.
     *
     * @experimental
     * @attribute true
     */
    readonly inputArn: string;
    /**
     * (experimental) Grant write permissions on this input and its contents to an IAM principal (Role/Group/User).
     *
     * @param grantee the principal.
     * @experimental
     */
    grantWrite(grantee: iam.IGrantable): iam.Grant;
    /**
     * (experimental) Grant the indicated permissions on this input to the given IAM principal (Role/Group/User).
     *
     * @param grantee the principal.
     * @param actions the set of actions to allow (i.e. "iotevents:BatchPutMessage").
     * @experimental
     */
    grant(grantee: iam.IGrantable, ...actions: string[]): iam.Grant;
}
declare abstract class InputBase extends Resource implements IInput {
    abstract readonly inputName: string;
    abstract readonly inputArn: string;
    /**
     * (experimental) Grant write permissions on this input and its contents to an IAM principal (Role/Group/User).
     *
     * @experimental
     */
    grantWrite(grantee: iam.IGrantable): iam.Grant;
    /**
     * (experimental) Grant the indicated permissions on this input to the given IAM principal (Role/Group/User).
     *
     * @experimental
     */
    grant(grantee: iam.IGrantable, ...actions: string[]): iam.Grant;
}
/**
 * (experimental) Properties for defining an AWS IoT Events input.
 *
 * @experimental
 */
export interface InputProps {
    /**
     * (experimental) The name of the input.
     *
     * @default - CloudFormation will generate a unique name of the input
     * @experimental
     */
    readonly inputName?: string;
    /**
     * (experimental) An expression that specifies an attribute-value pair in a JSON structure.
     *
     * Use this to specify an attribute from the JSON payload that is made available
     * by the input. Inputs are derived from messages sent to AWS IoT Events (BatchPutMessage).
     * Each such message contains a JSON payload. The attribute (and its paired value)
     * specified here are available for use in the condition expressions used by detectors.
     *
     * @experimental
     */
    readonly attributeJsonPaths: string[];
}
/**
 * (experimental) Defines an AWS IoT Events input in this stack.
 *
 * @experimental
 */
export declare class Input extends InputBase {
    /**
     * (experimental) Import an existing input.
     *
     * @experimental
     */
    static fromInputName(scope: Construct, id: string, inputName: string): IInput;
    /**
     * (experimental) The name of the input.
     *
     * @experimental
     */
    readonly inputName: string;
    /**
     * (experimental) The ARN of the input.
     *
     * @experimental
     */
    readonly inputArn: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: InputProps);
}
export {};
