import { Event } from './event';
import { Expression } from './expression';
import { CfnDetectorModel } from 'aws-cdk-lib/aws-iotevents';
/**
 * (experimental) Properties for options of state transition.
 *
 * @experimental
 */
export interface TransitionOptions {
    /**
     * (experimental) The name of the event.
     *
     * @default string combining the names of the States as `${originStateName}_to_${targetStateName}`
     * @experimental
     */
    readonly eventName?: string;
    /**
     * (experimental) The condition that is used to determine to cause the state transition and the actions.
     *
     * When this was evaluated to TRUE, the state transition and the actions are triggered.
     *
     * @experimental
     */
    readonly when: Expression;
}
/**
 * (experimental) Properties for defining a state of a detector.
 *
 * @experimental
 */
export interface StateProps {
    /**
     * (experimental) The name of the state.
     *
     * @experimental
     */
    readonly stateName: string;
    /**
     * (experimental) Specifies the events on enter.
     *
     * the conditions of the events are evaluated when the state is entered.
     * If the condition is `TRUE`, the actions of the event are performed.
     *
     * @default - events on enter will not be set
     * @experimental
     */
    readonly onEnter?: Event[];
}
/**
 * (experimental) Defines a state of a detector.
 *
 * @experimental
 */
export declare class State {
    private readonly props;
    /**
     * (experimental) The name of the state.
     *
     * @experimental
     */
    readonly stateName: string;
    private readonly transitionEvents;
    /**
     * @experimental
     */
    constructor(props: StateProps);
    /**
     * (experimental) Add a transition event to the state.
     *
     * The transition event will be triggered if condition is evaluated to TRUE.
     *
     * @param targetState the state that will be transit to when the event triggered.
     * @param options transition options including the condition that causes the state transition.
     * @experimental
     */
    transitionTo(targetState: State, options: TransitionOptions): void;
    /**
     * Collect states in dependency gragh that constructed by state transitions,
     * and return the JSONs of the states.
     * This function is called recursively and collect the states.
     *
     * @internal
     */
    _collectStateJsons(collectedStates: Set<State>): CfnDetectorModel.StateProperty[];
    /**
     * Returns true if this state has at least one condition via events.
     *
     * @internal
     */
    _onEnterEventsHaveAtLeastOneCondition(): boolean;
    private toStateJson;
}
